from fake_useragent.fake import UserAgent
from fake_useragent.utils import refresh
